@@ -153,9 +153,10 @@ class DockerComposeExecutor(object):
     def __init__(self, compose_files, project_name):
         self._compose_files = compose_files
         self._project_name = project_name
+        self.project_directory = os.path.dirname(os.path.realpath(compose_files[0]))
 
     def execute(self, *subcommand):
-        command = ["docker-compose"]
+        command = ["docker-compose", "--project-directory", self.project_directory]
         for compose_file in self._compose_files:
             command.append('-f')
             command.append(compose_file)
